package user

import (
	"fmt"
	"log"

	"github.com/spf13/cobra"
	"github.com/spf13/viper"
	ldap "github.com/go-ldap/ldap/v3"
)

func init() {
	// define user delete subcommand flags
	userDeleteCmd.Flags().StringP("base_ou", "o", "", "LDAP OU where your user entries are stored")
	userDeleteCmd.Flags().StringP("uid_attribute", "a", "uid", "LDAP DN attribute for users")
	userDeleteCmd.Flags().StringVarP(&flagUserUsername, "username", "u", "", "Username of user to delete")
	// bind config file values to user delete flags
	viper.BindPFlag("user.base_ou", userDeleteCmd.Flags().Lookup("base_ou"))
	viper.BindPFlag("user.uid_attr", userDeleteCmd.Flags().Lookup("uid_attribute"))
}

// define user delete subcommand
var userDeleteCmd = &cobra.Command{
	Use:   "delete",
	Short: "Delete an LDAP user from the directory",
	Long:  `Delete an LDAP user resource from the directory.`,
	Run: func(cmd *cobra.Command, args []string) {
		// create new LDAP connection
		l, err := ldap.Dial("tcp", fmt.Sprintf("%s:%d", viper.GetString("host"), viper.GetInt("port")))
		if err != nil {
			log.Fatal(err)
		}
		defer l.Close()

		// bind as the admin user
		err = l.Bind(viper.GetString("bind_dn"), viper.GetString("bind_pw"))
		if err != nil {
			log.Fatal(err)
		}

		// set up user DN
		userDn := fmt.Sprintf("%s=%s,%s", viper.GetString("user.uid_attr"), flagUserUsername, viper.GetString("user.base_ou"))

		// create a new delete request object
		deleteRequest := ldap.NewDelRequest(userDn, []ldap.Control{})

		// perform the delete operation
		err = l.Del(deleteRequest)
		if err != nil {
			log.Fatal(err)
		}
	},
}
